# frozen_string_literal: true

require "thor"

require "yapi/commands/fetch"
require "yapi/commands/init"

module YAPI
  class CLI < Thor
    class << self
      def exit_on_failure?
        true
      end
    end

    desc "fetch [filename]", "Fetch a request"
    long_desc <<-LONGDESC
      Fetches and prints the output of a request from a yapi.yml file.

        `yapi fetch path/to/yapi.yml:12`

      When a line number is not specified, `yapi` will prompt for a request name.

        `yapi fetch path/to/yapi.yml:12`

      When a line number is specified, `yapi` will run the nearest request to that line.
    LONGDESC
    def fetch(file_desc)
      YAPI::Commands::Fetch.new(file_desc).perform
    end

    desc "init", "Initialize a new YAPI project file"
    def init
      YAPI::Commands::Init.new.perform
    end
  end
end
