# frozen_string_literal: true

require "http"
require "fileutils"

module YAPI
  class Client
    def initialize(session_name)
      @session_name = session_name
    end

    def perform(req)
      YAPI::Response.new(HTTP.cookies(cookies)
                             .headers(req.headers)
                             .request(req.method, req.url, req.opts)).tap do |resp|
        update_cookies(resp.cookies)
      end
    end

    private

    def cookies
      @cookies ||= HTTP::CookieJar.new.tap do |jar|
                    jar.load(cookie_path) if @session_name && File.exist?(cookie_path)
                   end
    end

    def load_cookies
      if File.exist?(cookie_path)
        @cookies.load(cookie_path)
      end
    end

    def update_cookies(cookies)
      @cookies = cookies
      FileUtils.mkdir_p(cookie_dir)
      cookies.save(cookie_path)
    end

    def cookie_path
      File.expand_path("~/.cache/yapi/#{@session_name}.jar")
    end

    def cookie_dir
      File.dirname cookie_path
    end
  end
end
