# frozen_string_literal: true

require "tty-prompt"

require "yapi/fetcher"

module YAPI
  module Commands
    class Fetch
      def initialize(arg)
        match = arg.match(/(.*?):?(\d+)?$/)
        if match
          _, @filename, @line_number = match.to_a
        else
          @filename = arg
        end
      rescue StandardError => e
        puts e
      end

      def perform
        YAPI::Fetcher.new(config, route_name).perform
      end

      def route_name
        if @line_number
          find_route_name
        else
          prompt_route_name
        end
      end

      def find_route_name
        row = @line_number.to_i
        while row > 0 do
          match = lines[row - 1].match(/(^\S.*):$/)
          return match[1] if match
          row -= 1
        end
      end

      def prompt_route_name
        prompt.select("Choose request to run (Ctrl-C to exit):",
                      config.requests,
                      filter: true)
      end

      def lines
        @lines ||= File.readlines(@filename)
      end

      def config
        @config ||= YAPI::Config.new(@filename)
      end

      def prompt
        @prompt ||= TTY::Prompt.new(active_color: :bold, interrupt: :exit)
      end
    end
  end
end
