# frozen_string_literal: true

require "tty-prompt"

module YAPI
  module Commands
    class Init
      def perform
        create_config
      end

      private

      def create_config
        ask_filename
        ask_root
        write_file
        prompt.ok("Created #{@filename}")
      end

      def ask_filename
        @filename = prompt.ask("Filename:",
                               convert: :string,
                               default: "#{File.basename(Dir.getwd)}.yapi.yml")
        if File.exist? @filename
          prompt.warn("#{@filename} already exists, please choose another.")
          ask_filename
        end
      end

      def ask_root
        @root_path = prompt.ask("Root Path:",
                                convert: :string,
                                default: "http://localhost:3000")
      end

      def write_file
        contents = <<~HEREDOC
          ---
          root: #{@root_path}

          sample_route:
            path: /user
        HEREDOC
        File.write(@filename, contents)
      end

      def prompt
        @prompt ||= TTY::Prompt.new(interrupt: :exit, enable_color: false)
      end
    end
  end
end
