# frozen_string_literal: true

require "delegate"
require "uri"
require "yaml"

module YAPI
  class Config < ::SimpleDelegator

    SETTINGS_KEYS = %w[root headers output].freeze

    def initialize(filename)
      super(YAML.load(File.read(filename)))
    end

    def output_headers?
      fetch("output", {}).fetch("headers", true)
    end

    def session
      self["session"]
    end

    def root
      self["root"]
    end

    def headers
      fetch("headers", {})
    end

    def request(route_name)
      req = self[route_name]
      req.merge!("url" => URI.join(root, req["path"]))
      req["headers"] = headers.merge(req.fetch("headers", {}))
      YAPI::Request.new(req)
    end

    def requests
      keys - SETTINGS_KEYS
    end
  end
end
