# frozen_string_literal: true

require "delegate"

module YAPI
  class Response < ::SimpleDelegator
    def to_s(show_headers: true)
      String.new.tap do |out|
        out << "\n#{status}\n\n"
        out << header_str + "\n" if show_headers
        out << body_str
      end
    end 

    def header_str
      String.new.tap do |out|
        headers.each do |k, v|
          out << "#{k}: #{v}\n"
        end
      end
    end

    def body_str
      if self["Content-Type"] =~ /application\/json/
        JSON.pretty_generate(JSON.parse(body)).to_s
      else
        body.to_s
      end
    end
  end
end
